@@ -1,5 +1,5 @@
 '''
-Created by auto_sdk on 2020.11.01
+Created by auto_sdk on 2021.01.14
 '''
 from seven_top.top.api.base import RestApi
 class JstSmsMessageDirectBatchsendRequest(RestApi):
@@ -10,6 +10,8 @@ class JstSmsMessageDirectBatchsendRequest(RestApi):
 		self.sign_name = None
 		self.sms_content = None
 		self.sms_template_code = None
+		self.task_code = None
+		self.task_sign = None
 		self.url = None
 
 	def getapiname(self):
